==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QHBoxLayout_shell.h <==
#ifndef QHBOXLAYOUT_SHELL_H
#define QHBOXLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWidgets/qboxlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QHBoxLayout_shell : public QHBoxLayout, public QtJambiShellInterface
{
public:
    QHBoxLayout_shell();
    QHBoxLayout_shell(QWidget* parent0);
    ~QHBoxLayout_shell() override;

    void addItem(QLayoutItem* arg__1) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    int indexOf(QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int arg__1) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    void setGeometry(const QRect& arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHBoxLayout_access : public QHBoxLayout
{
};

#endif // QHBOXLAYOUT_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QHBoxLayout_shell.h <==
#ifndef QHBOXLAYOUT_SHELL_H
#define QHBOXLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qboxlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QHBoxLayout_shell : public QHBoxLayout, public QtJambiShellInterface
{
public:
    QHBoxLayout_shell();
    QHBoxLayout_shell(QWidget* parent0);
    ~QHBoxLayout_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QHBoxLayout_mshell;
    friend class QHBoxLayout_oshell;
};


class QHBoxLayout_mshell : public QHBoxLayout_shell
{
public:
    using QHBoxLayout_shell::QHBoxLayout_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QHBoxLayout_oshell : public QHBoxLayout_mshell
{
public:
    using QHBoxLayout_mshell::QHBoxLayout_mshell;
    void addItem(QLayoutItem* arg__1) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    int indexOf(const QLayoutItem* arg__1) const override;
    int indexOf(const QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int arg__1) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    QLayoutItem* replaceWidget(QWidget* from0, QWidget* to1, Qt::FindChildOptions options2) override;
    void setGeometry(const QRect& arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHBoxLayout_access : public QHBoxLayout
{
};

#endif // QHBOXLAYOUT_SHELL_H
